#!/usr/bin/python
#
# Copyright 2014 Canonical Ltd.  All rights reserved
# Author: Chris Stratford <chris.stratford@canonical.com>

import sys
import os
import json
sys.path.insert(0, os.path.join(os.environ['CHARM_DIR'], 'lib'))
from charmhelpers.core.hookenv import config, log

import yaml


class Config:
    def appName(self):
        return self.getConfig("application_name")

    def aptRepository(self):
        return self.getConfig("apt_repository")

    def aptRepositoryKey(self):
        return self.getConfig("apt_repository_key")

    def configDir(self):
        return self.getConfig("config_dir")

    def configFile(self):
        return os.path.join(self.configDir(), self.appName() + ".conf")

    def files(self):
        try:
            f = json.loads(self.getConfig("files"))
        except ValueError:
            log("CHARM: Unable to decode file config parameter")
            f = None
        return f

    def getConfig(self, what, default=""):
        if config(what):
            return config(what)
        else:
            return default

    def packageName(self):
        return self.getConfig("package_name")

    def serverPort(self):
        return self.getConfig("server_port")

    def spoolSize(self):
        return self.getConfig("spool_size")

    def servers(self):
        return self.getConfig("servers").split()

    def serversNameMap(self):
        value = self.getConfig("servers_name_map")
        if not value:
            return {}
        return yaml.safe_load(value)

    def sslCACert(self):
        return self.getConfig("ssl_ca_cert")

    def sslCACertFile(self):
        return os.path.join(self.configDir(), "logstash-forwarder-ca.crt")

    def sslCert(self):
        return self.getConfig("ssl_cert")

    def sslCertFile(self):
        return os.path.join(self.configDir(), "logstash-forwarder.crt")

    def sslKey(self):
        return self.getConfig("ssl_key")

    def sslKeyFile(self):
        return os.path.join(self.configDir(), "logstash-forwarder.key")

    def timeout(self):
        return self.getConfig("timeout")
